"""
Author:         David Szybala
Website:        www.davidszybala.com
Alt Website:    www.twistedgerbil.com
Program:        remove_namespaces.py
Date:           10/08/14
Description:    This script will rename all meshes from their parent transform
                name plus 'Shape'
Installation:   Place this file in your maya scripts directory
                (e.g. ..\My Documents\maya\scripts) then run the following
                python commands:
                    import rename_meshes
                    rename_meshes.main()
"""
import maya.cmds as cmds
from sys import stdout


class RenameMeshes(object):
    @staticmethod
    def get_meshes():
        """Returns a list of sorted mesh nodes"""
        meshes = cmds.ls(type='mesh', long=True, noIntermediate=True)
        meshes.sort()

        return meshes

    @staticmethod
    def get_base_name(long_name):
        """Returns the root name of 'long_name' """
        root_name = (long_name.split(":"))[-1]
        root_name = (root_name.split("|"))[-1]

        return root_name

    def get_mesh_name(self, mesh_object):
        """Returns the name of the parent for 'mesh_object' """
        mesh_name = 'NO_MESH_PARENT_FOUND'
        parent_node = cmds.listRelatives(mesh_object, fullPath=True,
                                         parent=True, type="transform")
        if parent_node:
            mesh_name = self.get_base_name(parent_node[0]) + 'Shape'

        return mesh_name


def main():
    """Main entry point. Executes the script"""
    rm = RenameMeshes()
    counter = 0

    for current in reversed(rm.get_meshes()):
        name = rm.get_mesh_name(current)
        final_name = cmds.rename(current, name)
        final_name = rm.get_base_name(final_name)
        if final_name != name:
            print('ERROR: Rename for object ' + current + ' failed.')
            print('   Attempted: ' + name)
            print('   Result: ' + final_name)
            counter += 1

    if counter == 0:
        stdout.write('INFO: All mesh nodes have been renamed')
    else:
        stdout.write('WARNING: Some mesh nodes could not be renamed. Check script editor')


if __name__ == '__main__':
    main()
